@@ -66,7 +66,7 @@ typedef struct isc_interface {
 #define INTERFACE_F_POINTTOPOINT	0x00000002U
 #define INTERFACE_F_LOOPBACK		0x00000004U
 #define INTERFACE_F_BROADCAST		0x00000008U
-#define INTERFACE_F_MULTICAST		0x00000010U
+// #define INTERFACE_F_MULTICAST	0x00000010U
 // #define INTERFACE_F_PRIVACY		0x00000020U	/* RFC 4941 */
 /*@}*/
 
