@@ -115,7 +115,9 @@ extern	const char *refid_str	(uint32_t, int);
 extern	int	decodenetnum	(const char *, sockaddr_u *);
 
 extern	void	signal_no_reset (int, void (*func)(int));
+#ifndef __NetBSD__
 extern void signal_no_reset1(int, void (*func)(int, siginfo_t *, void *));
+#endif
 
 extern	void	getauthkeys 	(const char *);
 
@@ -158,13 +160,6 @@ extern	size_t	strlcat(char *dst, const char *src, size_t siz);
 /* ntp_proto.c */
 extern double	measured_tick;		/* non-overridable sys_tick */
 
-#ifdef ENABLE_FUZZ
-/* systime.c */
-extern double	sys_tick;		/* tick size or time to read */
-extern double	sys_fuzz;		/* min clock read latency */
-extern bool	trunc_os_clock;		/* sys_tick > measured_tick */
-#endif
-
 /* use these as return values for sort-comparison functions */
 #define COMPARE_GREATERTHAN	1
 #define COMPARE_EQUAL		0
